@@ -102,6 +102,17 @@ sub parse
     {
       $doc->{web}->{request_filters}->{filter} = [ ];
     }# end if()
+    
+    $doc->{web}->{disable_peristence} ||= { };
+    if( $doc->{web}->{disable_peristence}->{location} )
+    {
+      $doc->{web}->{disable_peristence}->{location} = [ delete($doc->{web}->{disable_peristence}->{location}) ]
+        unless ref($doc->{web}->{disable_peristence}->{location}) eq 'ARRAY';
+    }
+    else
+    {
+      $doc->{web}->{disable_peristence}->{location} = [ ];
+    }# end if()
   };
   
   DATA_CONNECTIONS: {
